==> HTML-FormFu-2.05.tar.gz: HTML-FormFu-2.05/lib/HTML/FormFu/Constraint/File.pm <==
package HTML::FormFu::Constraint::File;

use strict;
our $VERSION = '2.05'; # VERSION

use Moose;
extends 'HTML::FormFu::Constraint';

use Scalar::Util qw( blessed );

sub constrain_value {
    my ( $self, $value ) = @_;

    return 1 if !defined $value || $value eq '';

    return blessed($value) && $value->isa('HTML::FormFu::Upload');
}

__PACKAGE__->meta->make_immutable;

1;

__END__

=head1 NAME

HTML::FormFu::Constraint::File - File Upload Constraint

=head1 VERSION

version 2.05

=head1 DESCRIPTION

Ensure the submitted value is a file upload.

This Constraint is not needed if you use any of the C<File::*> Constraints,
as they all make the same check as this Constraint does.

=head1 LIMITATIONS

This can only verify that your CGI backend (CGI, Catalyst, CGI::Simple)
thinks it was a file upload. If the user submits a filename which doesn't
exist on their system, you will probably get a valid L<HTML::FormFu::Upload>
object, with a valid filehandle, but no Content-Length. This Constraint
would still see this as a valid uploaded file - if you want to ensure that
you get a file with content, instead use
L<HTML::FormFu::Constraint::File::Size> with
L<min|HTML::FormFu::Constraint::File::Size/min> set to C<1>.

=head1 SEE ALSO

Is a sub-class of, and inherits methods from L<HTML::FormFu::Constraint>

L<HTML::FormFu>

=head1 AUTHOR

Carl Franks, C<cfranks@cpan.org>

=head1 LICENSE

This library is free software, you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut

==> HTML-FormFu-2.06.tar.gz: HTML-FormFu-2.06/lib/HTML/FormFu/Constraint/File.pm <==
use strict;

package HTML::FormFu::Constraint::File;
$HTML::FormFu::Constraint::File::VERSION = '2.06';
# ABSTRACT: File Upload Constraint

use Moose;
extends 'HTML::FormFu::Constraint';

use Scalar::Util qw( blessed );

sub constrain_value {
    my ( $self, $value ) = @_;

    return 1 if !defined $value || $value eq '';

    return blessed($value) && $value->isa('HTML::FormFu::Upload');
}

__PACKAGE__->meta->make_immutable;

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

HTML::FormFu::Constraint::File - File Upload Constraint

=head1 VERSION

version 2.06

=head1 DESCRIPTION

Ensure the submitted value is a file upload.

This Constraint is not needed if you use any of the C<File::*> Constraints,
as they all make the same check as this Constraint does.

=head1 LIMITATIONS

This can only verify that your CGI backend (CGI, Catalyst, CGI::Simple)
thinks it was a file upload. If the user submits a filename which doesn't
exist on their system, you will probably get a valid L<HTML::FormFu::Upload>
object, with a valid filehandle, but no Content-Length. This Constraint
would still see this as a valid uploaded file - if you want to ensure that
you get a file with content, instead use
L<HTML::FormFu::Constraint::File::Size> with
L<min|HTML::FormFu::Constraint::File::Size/min> set to C<1>.

=head1 SEE ALSO

Is a sub-class of, and inherits methods from L<HTML::FormFu::Constraint>

L<HTML::FormFu>

=head1 AUTHOR

Carl Franks, C<cfranks@cpan.org>

=head1 LICENSE

This library is free software, you can redistribute it and/or modify it under
the same terms as Perl itself.

=head1 AUTHOR

Carl Franks <cpan@fireartist.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018 by Carl Franks.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
